@@ -156,7 +156,7 @@ public abstract class AbstractOIDCBackend implements OIDCBackend {
 
     protected AbstractOIDCBackend() {
         super();
-        loginConfigurationReference = new AtomicReference<>(null);
+        loginConfigurationReference = new AtomicReference<LoginConfiguration>(null);
     }
 
     @Override
@@ -255,7 +255,8 @@ public abstract class AbstractOIDCBackend implements OIDCBackend {
         String login = userID + "@" + contextID;
         LOG.trace("getLoginRequest(...) login: {}", login);
         String defaultClient = loginConfiguration.getDefaultClient();
-        return LoginTools.parseLogin(request, login, null, false, defaultClient, loginConfiguration.isCookieForceHTTPS(), false);
+        LoginRequestImpl parseLogin = LoginTools.parseLogin(request, login, null, false, defaultClient, loginConfiguration.isCookieForceHTTPS(), false);
+        return parseLogin;
     }
 
     @Override
@@ -311,7 +312,7 @@ public abstract class AbstractOIDCBackend implements OIDCBackend {
             throw OIDCExceptionCode.UNABLE_TO_LOAD_USERINFO.create("unable to get a valid subject.");
         }
         AuthenticationInfo resultInfo = this.loadUserFromServer(subject);
-        resultInfo.setProperty(AUTH_RESPONSE, tokenResponse.toJSONObject().toJSONString());
+        resultInfo.getProperties().put(AUTH_RESPONSE, tokenResponse.toJSONObject().toJSONString());
         return resultInfo;
     }
 
@@ -356,7 +357,7 @@ public abstract class AbstractOIDCBackend implements OIDCBackend {
     public boolean updateOauthTokens(Session session) throws OXException {
         LOG.trace("updateOauthTokens(Session session: {})", session.getSessionID());
         AccessTokenResponse accessToken = this.loadAccessToken(session);
-        if (accessToken.getTokens() == null || accessToken.getTokens().getAccessToken() == null || accessToken.getTokens().getRefreshToken() == null) {
+        if (accessToken == null || accessToken.getTokens() == null || accessToken.getTokens().getAccessToken() == null || accessToken.getTokens().getRefreshToken() == null) {
             return false;
         }
         Map<String, String> tokenMap = new HashMap<>();
@@ -388,7 +389,9 @@ public abstract class AbstractOIDCBackend implements OIDCBackend {
                 throw OIDCExceptionCode.UNABLE_TO_RELOAD_ACCESSTOKEN.create(errorResponse.getErrorObject().getHTTPStatusCode() + " " + errorResponse.getErrorObject().getDescription());
             }
             return (AccessTokenResponse) response;
-        } catch (com.nimbusds.oauth2.sdk.ParseException | IOException e) {
+        } catch (com.nimbusds.oauth2.sdk.ParseException e) {
+            throw OIDCExceptionCode.UNABLE_TO_RELOAD_ACCESSTOKEN.create(e);
+        } catch (IOException e) {
             throw OIDCExceptionCode.UNABLE_TO_RELOAD_ACCESSTOKEN.create(e);
         }
     }
@@ -568,13 +571,13 @@ public abstract class AbstractOIDCBackend implements OIDCBackend {
         LOG.trace("loginUser(HttpServletRequest request: {}, final Context context: {}, final User user: {}, final Map<String, String> state.size: {}, final String oidcAutologinCookieValue: {})", request.getRequestURI(), context.getContextId(), user.getId(), state.size(), oidcAutologinCookieValue);
         final LoginRequest loginRequest = this.getLoginRequest(request, user.getId(), context.getContextId(), getLoginConfiguration());
 
-        return LoginPerformer.getInstance().doLogin(loginRequest, new HashMap<String, Object>(), new LoginMethodClosure() {
+        LoginResult loginResult = LoginPerformer.getInstance().doLogin(loginRequest, new HashMap<String, Object>(), new LoginMethodClosure() {
 
             @Override
             public Authenticated doAuthentication(LoginResultImpl loginResult) throws OXException {
                 Authenticated authenticated = enhanceAuthenticated(getDefaultAuthenticated(context, user), state);
 
-                return new EnhancedAuthenticated(authenticated) {
+                EnhancedAuthenticated enhanced = new EnhancedAuthenticated(authenticated) {
 
                     @Override
                     protected void doEnhanceSession(Session session) {
@@ -589,8 +592,12 @@ public abstract class AbstractOIDCBackend implements OIDCBackend {
                         session.setParameter(OIDCTools.BACKEND_PATH, getPath());
                     }
                 };
+
+                return enhanced;
             }
         });
+
+        return loginResult;
     }
 
     private Authenticated getDefaultAuthenticated(final Context context, final User user) {
