@@ -69,7 +69,7 @@ import com.openexchange.oidc.OIDCProperty;
  */
 public abstract class AbstractOIDCBackendConfig implements OIDCBackendConfig {
 
-    private static final Logger LOG = LoggerFactory.getLogger(AbstractOIDCBackendConfig.class);
+    private final static Logger LOG = LoggerFactory.getLogger(AbstractOIDCBackendConfig.class);
 
     /** The reference to tracked <code>LeanConfigurationService</code> */
     protected final LeanConfigurationService leanConfigurationService;
@@ -185,11 +185,10 @@ public abstract class AbstractOIDCBackendConfig implements OIDCBackendConfig {
     @Override
     public boolean isAutologinEnabled() {
         boolean result = false;
-        String autologinCookieMode = this.autologinCookieMode();
-        AutologinMode autologinMode = OIDCBackendConfig.AutologinMode.get(autologinCookieMode);
+        AutologinMode autologinMode = OIDCBackendConfig.AutologinMode.get(this.autologinCookieMode());
 
         if (autologinMode == null) {
-            LOG.debug("Unknown value for parameter com.openexchange.oidc.autologinCookieMode. Value is: {}", autologinCookieMode);
+            LOG.debug("Unknown value for parameter com.openexchange.oidc.autologinCookieMode. Value is: {}", this.autologinCookieMode());
         } else {
             result = (autologinMode == AutologinMode.OX_DIRECT || autologinMode == AutologinMode.SSO_REDIRECT);
         }
@@ -260,15 +259,8 @@ public abstract class AbstractOIDCBackendConfig implements OIDCBackendConfig {
             }
 
             @Override
-            public <T extends Object> T getDefaultValue(Class<T> clazz) throws IllegalArgumentException {
-                Object defaultValue = backendProperty.getDefaultValue();
-                if (null == defaultValue) {
-                    return null;
-                }
-                if (clazz.isAssignableFrom(defaultValue.getClass())) {
-                    return clazz.cast(defaultValue);
-                }
-                throw new IllegalArgumentException("The object cannot be converted to the specified type '" + clazz.getCanonicalName() + "'");
+            public Object getDefaultValue() {
+                return backendProperty.getDefaultValue();
             }
         };
     }
