@@ -52,7 +52,7 @@ package com.openexchange.oidc;
  * Configuration of the OpenID Connect Feature.
  *
  * @author <a href="mailto:vitali.sjablow@open-xchange.com">Vitali Sjablow</a>
- * @since v7.8.4
+ * @since v7.10.0
  */
 public interface OIDCConfig {
     
@@ -61,13 +61,13 @@ public interface OIDCConfig {
      * 
      * @return true or false
      */
-    boolean isEnabled();
+    Boolean isEnabled();
     
     /**
      * Start the default core OIDC backend.
      * 
      * @return true or false
      */
-    boolean startDefaultBackend();
+    Boolean startDefaultBackend();
     
 }
